<?php

/**
 * @file
 * Contains \Drupal\commerce_store_filter\Form
 * Store selection form for multi-store 
 * 
 */
namespace Drupal\commerce_store_filter\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
/**
 * Class StoreSelectForm for store selection.
*/
class StoreSelectForm extends FormBase {

  /**
   * {@inheritdoc}
  */
  public function getFormId() {
    return 'commerce_store_select_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $store_list = [];
    $stores = \Drupal::database()
      ->select('commerce_store_field_data', 'cs')
      ->fields('cs', ['store_id', 'name', 'default_currency'])
      ->execute()
      ->fetchAll();

    foreach ($stores as $value) {
      $store_list[$value->store_id] = $value->name . "(" . $value->default_currency . ")";
    }

    $store_storage = \Drupal::entityTypeManager()->getStorage('commerce_store');
    $store_id = $store_storage->loadDefault()->id();
    $session = \Drupal::request()->getSession();
    if (is_object($session)) {
      $store_id = $session->get('commerce_store_filter_store');
      if(empty($store_id) || !is_numeric($store_id)) {
        $store_id = $store_storage->loadDefault()->id();
      }      
    }
    $form['store'] = [
      '#type' => 'select',
      '#title' => $this->t('Change Store'),
      '#options' => $store_list,
      '#default_value' => $store_id,
      '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Switch'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
  */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Nothing.
  }
  
  /**
   * {@inheritdoc}
  */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $store_id = $form_state->getValue('store');
    $session = \Drupal::request()->getSession();
    $session->set('commerce_store_filter_store', $store_id); // Saving the session for the access.
    \Drupal::messenger()->addMessage('Store has been switched successfully!');
  }

}
