<?php

namespace Drupal\commerce_store_filter\Resolver;

use Drupal\commerce_store\Resolver\StoreResolverInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

class StoreFilterResolver implements StoreResolverInterface {

  /**
   * The store storage.
   *
   * @var \Drupal\commerce_store\StoreStorageInterface
   */
  protected $storage;

  /**
   * Constructs a new DefaultStoreResolver object.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->storage = $entity_type_manager->getStorage('commerce_store');
  }

  /**
   * {@inheritdoc}
   */
  public function resolve() {
    $store_storage = \Drupal::entityTypeManager()->getStorage('commerce_store');
    $store_id = $store_storage->loadDefault()->id();
    $session = \Drupal::request()->getSession();
    if (is_object($session)) {
      $store_id = $session->get('commerce_store_filter_store');
      if(empty($store_id) || !is_numeric($store_id)) {
        $store_id = $store_storage->loadDefault()->id();
      }      
    }
    return $this->storage->load($store_id);
  }

}
